use dioxus::prelude::*;

use crate::modrinth::tags::game_versions::{get_game_versions, GameVersion};

#[component]
pub fn New() -> Element {
    let game_versions = use_resource(|| async move {
        let response = get_game_versions().await;

        match response {
            Ok(r) => Ok(r
                .into_iter()
                .filter(|v| v.major == true)
                .collect::<Vec<GameVersion>>()),
            Err(err) => Err(err),
        }
    });

    rsx! {
        div {
            class: "max-w-md w-full mx-auto",
            h2 { class: "text-2xl font-bold mt-20", "Create a new modpack" }
            form {
                class: "mt-10",
                input { r#type: "text", placeholder: "Name", class: "input input-bordered w-full" }
                div {
                    class: "flex gap-5 mt-6",
                    select {
                        class: "select select-bordered w-full",
                        option { disabled: true, selected: true, "Minecraft Version" },
                        match &*game_versions.read_unchecked() {
                            Some(Ok(response)) => rsx! {
                                for game_version in response {
                                    option { "{game_version.version}" }
                                }
                            },
                            _ => rsx! { option { disabled: true, "Loading..." } }
                        }
                    }
                    select {
                        class: "select select-bordered",
                        option { disabled: true, selected: true, "Modloader" },
                        option { "Fabric" },
                        option { "Quilt" },
                        option { "Forge" },
                        option { "Neoforge" },
                    }
                }
                button { class: "btn btn-primary mt-10 w-full", "Submit" }
            }
        }
    }
}
